@@ -77,6 +77,7 @@ struct _EogPrintPreviewPrivate {
 /* Signal IDs */
 enum {
 	SIGNAL_IMAGE_MOVED,
+	SIGNAL_IMAGE_SCALED,
 	SIGNAL_LAST
 };
 static gint preview_signals [SIGNAL_LAST];
@@ -388,6 +389,19 @@ eog_print_preview_class_init (EogPrintPreviewClass *klass)
 			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE,
 			      0, NULL);
 
+/**
+ * EogPrintPreview::image-scaled:
+ * @preview: the object which received the signal
+ *
+ * The ::image-scaled signal is emmited when the scale of the image is changed.
+ */
+	preview_signals [SIGNAL_IMAGE_SCALED] =
+		g_signal_new ("image_scaled",
+			      G_TYPE_FROM_CLASS (gobject_class),
+			      G_SIGNAL_RUN_FIRST, 0, NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE,
+			      0, NULL);
+
 	g_type_class_add_private (klass, sizeof (EogPrintPreviewPrivate));
 }
 
@@ -516,6 +530,7 @@ eog_print_preview_new (void)
 			       GDK_POINTER_MOTION_MASK      |
 			       GDK_BUTTON_PRESS_MASK        |
 			       GDK_BUTTON_RELEASE_MASK      |
+			       GDK_SCROLL_MASK              |
 			       GDK_KEY_PRESS_MASK);
 
 	g_object_set (G_OBJECT (area),
@@ -619,6 +634,16 @@ press_inside_image_area (EogPrintPreview *preview,
 	return FALSE;
 }
 
+gboolean
+eog_print_preview_point_in_image_area (EogPrintPreview *preview,
+				       guint x,
+				       guint y)
+{
+	g_return_val_if_fail (EOG_IS_PRINT_PREVIEW (preview), FALSE);
+
+	return press_inside_image_area (preview, x, y);
+}
+
 static void
 create_image_scaled (EogPrintPreview *preview)
 {
@@ -1214,4 +1239,31 @@ eog_print_preview_set_scale (EogPrintPreview *preview,
 	g_object_set (preview,
 		      "image-scale", scale,
 		      NULL);
+
+	g_signal_emit (G_OBJECT (preview),
+		       preview_signals
+		       [SIGNAL_IMAGE_SCALED], 0);
+
+}
+
+/**
+ * eog_print_preview_get_scale:
+ * @preview: A #EogPrintPreview.
+ *
+ * Gets the scale for the image.
+ *
+ * Returns: The scale for the image.
+ **/
+gfloat
+eog_print_preview_get_scale (EogPrintPreview *preview)
+{
+	gfloat scale;
+
+	g_return_val_if_fail (EOG_IS_PRINT_PREVIEW (preview), 0);
+
+	g_object_get (preview,
+		      "image-scale", &scale,
+		      NULL);
+
+	return scale;
 }
