@@ -13,7 +13,6 @@
 
 #include "eog-config-keys.h"
 #include "eog-enum-types.h"
-#include "eog-marshal.h"
 #include "eog-scroll-view.h"
 #include "eog-debug.h"
 #if 0
@@ -2512,7 +2511,8 @@ eog_scroll_view_init (EogScrollView *view)
 
 	gtk_drag_source_set (priv->display, GDK_BUTTON1_MASK,
 			     target_table, G_N_ELEMENTS (target_table),
-			     GDK_ACTION_COPY);
+			     GDK_ACTION_COPY | GDK_ACTION_MOVE |
+			     GDK_ACTION_LINK | GDK_ACTION_ASK);
 	g_signal_connect (G_OBJECT (priv->display), "drag-data-get",
 			  G_CALLBACK (view_on_drag_data_get_cb), view);
 	g_signal_connect (G_OBJECT (priv->display), "drag-begin",
@@ -2822,7 +2822,7 @@ eog_scroll_view_class_init (EogScrollViewClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (EogScrollViewClass, zoom_changed),
 			      NULL, NULL,
-			      eog_marshal_VOID__DOUBLE,
+			      g_cclosure_marshal_VOID__DOUBLE,
 			      G_TYPE_NONE, 1,
 			      G_TYPE_DOUBLE);
 
